;**********************************************************************

;   This file is a basic code template for assembly code generation   *

;   on the PICmicro PIC16F84. This file contains the basic code       *

;   building blocks to build upon.                                    *  

;                                                                     *

;   If interrupts are not used all code presented between the ORG     *

;   0x004 directive and the label main can be removed. In addition    *

;   the variable assignments for 'w_temp' and 'status_temp' can       *

;   be removed.                                                       *                        

;                                                                     *

;   Refer to the MPASM User's Guide for additional information on     *

;   features of the assembler (Document DS33014).                     *

;                                                                     *

;   Refer to the respective PICmicro data sheet for additional        *

;   information on the instruction set.                               *

;                                                                     *

;   Template file assembled with MPASM V2.11.01                       *

;                                                                     *

;**********************************************************************

;                                                                     *

;    Filename:	    mlrs232.asm                                       *

;    Date:          1998-07-27                                        *

;    File Version:  0.2                                               *

;                                                                     *

;    Author:        Ake Hedman (akhe@eurosource.se)                   *

;    Company:       Eurosource, Sweden                                *

;                   http://www.eurosource.se                          * 

;								      *

;	(c) 1998 Eurosource, Sweden				      *

;	portions (c) 1997 Pavel Korensky <pavelk@dator3.anet.cz>      *

;                                                                     *

;**********************************************************************

;                                                                     *

;    Files required:                                                  *

;                   	p16F84.inc                                    *

;                       1wire.asm                                     *

;			rs232.h					      *

;			rcvr.asm				      *

;			txmtr.asm				      *	

;                                                                     *

;**********************************************************************

;                                                                     *

;    Notes:                                                           *

;            This code is free code that you can use in whatever      *                                                    

;            way you like. The code                                     

;                                                                     *

;                                                                     *

;**********************************************************************





	list      p=12c508a           ; list directive to define processor

	#include <p12c508a.inc>       ; processor specific variable definitions



	__CONFIG   _CP_OFF & _WDT_ON & _MCLRE_ON & _IntRC_OSC 



; '__CONFIG' directive is used to embed configuration word within .asm file.

; The lables following the directive are located in the respective .inc file.

; See respective data sheet for additional information on configuration word.





TRUE	equ	1

FALSE	equ	0



temp		EQU	0x07	; General temporary storage



;*********************************************************************************************************

;                               Dallas 1-Wire

;*********************************************************************************************************



; ROM Storage  -  08,09,0A,0B,0C,0D,0E,0F



rom		EQU	0x08 

rom_serial	EQU	0x09

rom_crc		EQU	0x0F



#define		FAMILY_CODE	ROM



; Scartch PAD  8 bytes + CRC  -  10, 11, 12, 13, 14, 15, 16, 17



scrpad		EQU	0x11

scrpad_crc	EQU	0x17



DS_PORT		EQU	GPIO	; Dallas port

DS_BIT		EQU	0	; Dallas bit



; byte 1 (Status)

; ===============

; Bit 7 - Device is selected

; Bit 6 - Alarm condition

; Bit 5 - Scratchpad Written

; Bit 4 - Scratchpad Read

; Bit 0 - Powered from 1-Wire



ds_status	EQU	0x18	; Device status



#define	DS_SELECTED	7	; bit 7 - Device is selected.

#define	DS_ALARM	6	; bit 6 - Alarm Condition.

#define DS_SCRPAD_W	5	; bit 5 - Scartchpad written.

#define DS_SCRPAD_R	4	; bit 4 - Scartchpad read.

#define DS_POWER	0	; bit 0 - Powered from 1-Wire.



ds_command		EQU	0x19

ds_bit_index		EQU	0x1A	; current bit index 1-8



ds_rom_bit_index	EQU	0x1B	; current rom bit 1-64

ds_state		EQU	0x1C	; state machine



crc8			EQU	0x1D



delay			EQU	0x1E



;crc16_low		EQU	0x1E

;crc16_high		EQU	0x1F



;ds_temp1		EQU	0x28

;ds_temp2		EQU	0x29







;==============================================================================

;				General Storage

;==============================================================================







;==============================================================================

;			   E E P R O M     D A T A

;==============================================================================



;		ORG	H'2100'		; EEPROM



; 1-Wire ROM Code

;

; Family Code F1

; ==============

; Always use 0x90

;

; Serial number S1-S6

; ===================

; The code should be 194.17.255.240.a.b where 194.17.255.240 is a Eurosource specific

; number. 194.17.255.240 is the Internet class supplied to Eurosource. Use your

; own net here or 192.168.a.b.c.d if you don't have your own net. This ensures 

; that all devices have a unique address and can interoperate.



;F1	DB	0x090

;S1	DB	0x001	; LSB of serial number

;S2	DB	0x000	

;S3	DB	0x0F0

;S4	DB	0x0FF

;S5	DB	0x011

;S6	DB	0x0C2	; MSB of serial number



;DEVICE_NAME:	DE	"1-Wire slave ver 0.1",0	; Device name



;==============================================================================

;			       P R O G R A M

;==============================================================================



		ORG     0x000           ; processor reset vector

  		goto    main            ; go to beginning of program





;==============================================================================

; 				Configure ports

;

; Configure TX Pin as output, make sure TX Pin Comes up in high state on 

; Reset Configure, RX_Pin (RTCC pin) as Input, which is used to poll data 

; on reception.

;

;==============================================================================



InitMemory:

		return



InitPorts:	

		return



Init1Wire:

		return



WaitForLow:

		incf	temp		; 1

		btfsc	DS_PORT,DS_BIT	; 1

		goto	WaitForLow	; 2

		return			; 1



WaitForHigh:

		incf	temp

		btfss	DS_PORT,DS_BIT

		goto	WaitForHigh

		return

		

WaitForReset:

		call 	WaitForLow



		; low signal detected



		clrf	temp

		call	WaitForHigh

		

		; if temp1 > 120 we have a reset

		



		return

;==============================================================================

;			 * * * *     M A I N     * * * *

;==============================================================================		



main:

		call 	InitPorts	; Initiate other ports

		call	InitMemory	; initialize memory	

		call	Init1Wire	; Initialize the 1-wire system



		call	WaitForReset	







		end                     ; directive 'end of program'		

